@@ -87,17 +87,17 @@ static void build_hash_table(struct sum_struct *s)
 }
 
 
-static off_t last_match;
+static OFF_T last_match;
 
 
 static void matched(int f,struct sum_struct *s,struct map_struct *buf,
-		    off_t offset,int i)
+		    OFF_T offset,int i)
 {
-	off_t n = offset - last_match;
+	OFF_T n = offset - last_match;
 	int j;
 
 	if (verbose > 2 && i >= 0)
-		fprintf(FINFO,"match at %d last_match=%d j=%d len=%d n=%d\n",
+		rprintf(FINFO,"match at %d last_match=%d j=%d len=%d n=%d\n",
 			(int)offset,(int)last_match,i,(int)s->sums[i].len,(int)n);
 
 	send_token(f,i,buf,last_match,n,i==-1?0:s->sums[i].len);
@@ -123,34 +123,34 @@ static void matched(int f,struct sum_struct *s,struct map_struct *buf,
 
 
 static void hash_search(int f,struct sum_struct *s,
-			struct map_struct *buf,off_t len)
+			struct map_struct *buf,OFF_T len)
 {
-	off_t offset;
+	OFF_T offset;
 	int j,k;
 	int end;
 	char sum2[SUM_LENGTH];
 	uint32 s1, s2, sum; 
-	signed char *map;
+	schar *map;
 
 	if (verbose > 2)
-		fprintf(FINFO,"hash search b=%d len=%d\n",s->n,(int)len);
+		rprintf(FINFO,"hash search b=%d len=%d\n",s->n,(int)len);
 
 	k = MIN(len, s->n);
 	
-	map = (signed char *)map_ptr(buf,0,k);
+	map = (schar *)map_ptr(buf,0,k);
 	
 	sum = get_checksum1((char *)map, k);
 	s1 = sum & 0xFFFF;
 	s2 = sum >> 16;
 	if (verbose > 3)
-		fprintf(FINFO, "sum=%.8x k=%d\n", sum, k);
+		rprintf(FINFO, "sum=%.8x k=%d\n", sum, k);
 	
 	offset = 0;
 	
 	end = len + 1 - s->sums[s->count-1].len;
 	
 	if (verbose > 3)
-		fprintf(FINFO,"hash search s->n=%d len=%d count=%d\n",
+		rprintf(FINFO,"hash search s->n=%d len=%d count=%d\n",
 			s->n,(int)len,s->count);
 	
 	do {
@@ -159,7 +159,7 @@ static void hash_search(int f,struct sum_struct *s,
 			
 		j = tag_table[t];
 		if (verbose > 4)
-			fprintf(FINFO,"offset=%d sum=%08x\n",(int)offset,sum);
+			rprintf(FINFO,"offset=%d sum=%08x\n",(int)offset,sum);
 		
 		if (j == NULL_TAG) {
 			goto null_tag;
@@ -173,12 +173,12 @@ static void hash_search(int f,struct sum_struct *s,
 			if (sum != s->sums[i].sum1) continue;
 			
 			if (verbose > 3)
-				fprintf(FINFO,"potential match at %d target=%d %d sum=%08x\n",
+				rprintf(FINFO,"potential match at %d target=%d %d sum=%08x\n",
 					(int)offset,j,i,sum);
 			
 			if (!done_csum2) {
 				int l = MIN(s->n,len-offset);
-				map = (signed char *)map_ptr(buf,offset,l);
+				map = (schar *)map_ptr(buf,offset,l);
 				get_checksum2((char *)map,l,sum2);
 				done_csum2 = 1;
 			}
@@ -191,7 +191,7 @@ static void hash_search(int f,struct sum_struct *s,
 			matched(f,s,buf,offset,i);
 			offset += s->sums[i].len - 1;
 			k = MIN((len-offset), s->n);
-			map = (signed char *)map_ptr(buf,offset,k);
+			map = (schar *)map_ptr(buf,offset,k);
 			sum = get_checksum1((char *)map, k);
 			s1 = sum & 0xFFFF;
 			s2 = sum >> 16;
@@ -201,7 +201,7 @@ static void hash_search(int f,struct sum_struct *s,
 		
 	null_tag:
 		/* Trim off the first byte from the checksum */
-		map = (signed char *)map_ptr(buf,offset,k+1);
+		map = (schar *)map_ptr(buf,offset,k+1);
 		s1 -= map[0] + CHAR_OFFSET;
 		s2 -= k * (map[0]+CHAR_OFFSET);
 		
@@ -220,7 +220,7 @@ static void hash_search(int f,struct sum_struct *s,
 }
 
 
-void match_sums(int f,struct sum_struct *s,struct map_struct *buf,off_t len)
+void match_sums(int f,struct sum_struct *s,struct map_struct *buf,OFF_T len)
 {
 	char file_sum[MD4_SUM_LENGTH];
 
@@ -236,12 +236,12 @@ void match_sums(int f,struct sum_struct *s,struct map_struct *buf,off_t len)
 		build_hash_table(s);
 		
 		if (verbose > 2) 
-			fprintf(FINFO,"built hash table\n");
+			rprintf(FINFO,"built hash table\n");
 		
 		hash_search(f,s,buf,len);
 		
 		if (verbose > 2) 
-			fprintf(FINFO,"done hash search\n");
+			rprintf(FINFO,"done hash search\n");
 	} else {
 		matched(f,s,buf,len,-1);
 	}
@@ -250,7 +250,7 @@ void match_sums(int f,struct sum_struct *s,struct map_struct *buf,off_t len)
 
 	if (remote_version >= 14) {
 		if (verbose > 2)
-			fprintf(FINFO,"sending file_sum\n");
+			rprintf(FINFO,"sending file_sum\n");
 		write_buf(f,file_sum,MD4_SUM_LENGTH);
 	}
 
@@ -260,7 +260,7 @@ void match_sums(int f,struct sum_struct *s,struct map_struct *buf,off_t len)
 	}
 	
 	if (verbose > 2)
-		fprintf(FINFO, "false_alarms=%d tag_hits=%d matches=%d\n",
+		rprintf(FINFO, "false_alarms=%d tag_hits=%d matches=%d\n",
 			false_alarms, tag_hits, matches);
 	
 	total_tag_hits += tag_hits;
@@ -274,7 +274,7 @@ void match_report(void)
 	if (verbose <= 1)
 		return;
 
-	fprintf(FINFO,
+	rprintf(FINFO,
 		"total: matches=%d  tag_hits=%d  false_alarms=%d  data=%ld\n",
 		total_matches,total_tag_hits,
 		total_false_alarms,(long)total_data_transfer);
